@@ -9,10 +9,12 @@ E-mail  :   windprog@gmail.com
 Date    :   14-12-2
 Desc    :   
 """
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 __author__ = "Windpro"
+__author_email__ = "windprog@gmail.com"
 __description__ = "High performance http engine, Support Django."
 __title__ = 'httpappengine'
+__url__ = "https://github.com/windprog/appengine"
 
 from .decorator import url
 from .helper import rest
